#
# spec file for package ghc-ede
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name ede
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.8.4
Release:        8.8
Summary:        Templating language with similar syntax and features to Liquid or Jinja2
License:        MPL-2.0
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-ansi-wl-pprint-devel
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-free-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-parsers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-semigroups-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-format-devel
BuildRequires:  ghc-text-manipulate-devel
BuildRequires:  ghc-trifecta-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
%endif

%description
ED-E is a templating language written in Haskell with a specific set of
features:

* Logicless within reason. A small set of consistent predicates and expressions
for formatting and presentational logic are provided.

* Secure. No arbitrary code evaluation, with input data required to be fully
specified at render time.

* Stateless. Parsing and rendering are separate steps so that loading, parsing,
include resolution, and embedding of the compiled template can optionally be
done ahead of time, amortising cost.

* Markup agnostic. ED-E is used to write out everything from configuration
files for system services, to HTML and formatted emails.

* Control over purity. Users can choose pure or IO-based resolution of
'include' expressions.

* No surprises. All parsing, type assurances, and rendering steps report
helpful error messages with line/column metadata. Variable shadowing,
unprintable expressions, implicit type coercion, and unbound variable access
are all treated as errors.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE
%dir %{_datadir}/%{pkg_name}-%{version}
%dir %{_datadir}/%{pkg_name}-%{version}/test
%dir %{_datadir}/%{pkg_name}-%{version}/test/resources
%{_datadir}/%{pkg_name}-%{version}/test/resources/*.ede
%{_datadir}/%{pkg_name}-%{version}/test/resources/*.golden

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.md

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2.8.4 revision 0 with cabal2obs.
